LabelName

Enum LabelName 

#[non_exhaustive]
pub enum LabelName {
Show 17 variants AllureId, Suite, ParentSuite, SubSuite, Epic, Feature, Story, Severity, Tag, Owner, Host, Thread, TestMethod, TestClass, Package, Framework, Language,
}
Reserved label names used by Allure for special purposes.

Variants (Non-exhaustive)

This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.


AllureId

Allure test case ID (AS_ID)



Suite

Test suite name



ParentSuite

Parent suite name



SubSuite

Sub-suite name



Epic

Epic (top-level business capability)



Feature

Feature under epic



Story

User story under feature



Severity

Test severity



Tag

Test tag



Owner

Test owner/maintainer



Host

Execution host



Thread

Thread ID



TestMethod

Test method name



TestClass

Test class name



Package

Package/module name



Framework

Test framework name



Language

Programming language

Implementations

Source

impl LabelName

pub fn as_str(&self) -> &'static str

Returns the string name used in Allure JSON.